==> zio-aws-networkmanager_3-5.17.154.1-sources.jar: zio/aws/networkmanager/model/UpdateGlobalNetworkResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateGlobalNetworkResponse(
    globalNetwork: Option[zio.aws.networkmanager.model.GlobalNetwork] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse = {
    import UpdateGlobalNetworkResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
      .builder()
      .optionallyWith(globalNetwork.map(value => value.buildAwsValue()))(
        _.globalNetwork
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.UpdateGlobalNetworkResponse.ReadOnly =
    zio.aws.networkmanager.model.UpdateGlobalNetworkResponse
      .wrap(buildAwsValue())
}
object UpdateGlobalNetworkResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.UpdateGlobalNetworkResponse =
      zio.aws.networkmanager.model.UpdateGlobalNetworkResponse(
        globalNetwork.map(value => value.asEditable)
      )
    def globalNetwork
        : Option[zio.aws.networkmanager.model.GlobalNetwork.ReadOnly]
    def getGlobalNetwork: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.GlobalNetwork.ReadOnly
    ] = AwsError.unwrapOptionField("globalNetwork", globalNetwork)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
  ) extends zio.aws.networkmanager.model.UpdateGlobalNetworkResponse.ReadOnly {
    override val globalNetwork
        : Option[zio.aws.networkmanager.model.GlobalNetwork.ReadOnly] = scala
      .Option(impl.globalNetwork())
      .map(value => zio.aws.networkmanager.model.GlobalNetwork.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
  ): zio.aws.networkmanager.model.UpdateGlobalNetworkResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_3-6.20.61.1-sources.jar: zio/aws/networkmanager/model/UpdateGlobalNetworkResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateGlobalNetworkResponse(
    globalNetwork: Optional[zio.aws.networkmanager.model.GlobalNetwork] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse = {
    import UpdateGlobalNetworkResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
      .builder()
      .optionallyWith(globalNetwork.map(value => value.buildAwsValue()))(
        _.globalNetwork
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.UpdateGlobalNetworkResponse.ReadOnly =
    zio.aws.networkmanager.model.UpdateGlobalNetworkResponse
      .wrap(buildAwsValue())
}
object UpdateGlobalNetworkResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.UpdateGlobalNetworkResponse =
      zio.aws.networkmanager.model.UpdateGlobalNetworkResponse(
        globalNetwork.map(value => value.asEditable)
      )
    def globalNetwork
        : Optional[zio.aws.networkmanager.model.GlobalNetwork.ReadOnly]
    def getGlobalNetwork: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.GlobalNetwork.ReadOnly
    ] = AwsError.unwrapOptionField("globalNetwork", globalNetwork)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
  ) extends zio.aws.networkmanager.model.UpdateGlobalNetworkResponse.ReadOnly {
    override val globalNetwork
        : Optional[zio.aws.networkmanager.model.GlobalNetwork.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.globalNetwork())
        .map(value => zio.aws.networkmanager.model.GlobalNetwork.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.UpdateGlobalNetworkResponse
  ): zio.aws.networkmanager.model.UpdateGlobalNetworkResponse.ReadOnly =
    new Wrapper(impl)
}
